@@ -1,12 +1,14 @@
 pub mod common;
 pub mod mpmc;
 pub mod option;
+pub mod pubsub;
 pub mod ring;
 pub mod spsc;
 pub mod vec;
 
 pub use mpmc::Mpmc;
-pub use option::AtomicOption;
+pub use option::{AtomicOption, Seek};
+pub use pubsub::{Publisher, Subscriber};
 pub use ring::AtomicRing;
 pub use spsc::Spsc;
 pub use vec::AtomicVec;
